"""correct resubmit url

Revision ID: 702a4a776f9b
Revises: a67188cd0701
Create Date: 2022-01-21 09:26:12.723891

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "702a4a776f9b"
down_revision = "a67188cd0701"
branch_labels = None
depends_on = None

script = """#!/usr/bin/env bash

set -o errexit -o nounset

# This script is for resubmitting a manually altered standard calibration.
# A new capability request version will be created and all relevant files 
# from the previous version results (contained in the current directory) will be appended to it.

CAPABILITY_SERVICE=$(capo -q edu.nrao.workspaces.CapabilitySettings.externalServiceUrl)

# create new request version
data_location={{spool_dir}}/rawdata
if [[ -L $data_location ]]; then
    qa="qa2"
    corrected_location="${data_location/spool/"$qa"}"
    params="{"resubmit": true, "rawdata_dir":"location"}"
    corrected_params="${params/location/"$corrected_location"}"
    capability_request_id=$(curl --header "Content-Type: application/json" --request POST --data "$corrected_params" $CAPABILITY_SERVICE/capability/request/execution/{{request_id}}/create_version)
else
    params="{"resubmit": true, "rawdata_dir":"location"}"
    corrected_params="${params/location/"$data_location"}"
    capability_request_id=$(curl --header "Content-Type: application/json" --request POST --data "$corrected_params" $CAPABILITY_SERVICE/capability/request/execution/{{request_id}}/create_version)
fi
# add all files in current directory to new version

# sort files for valid additions
echo "Sorting files...."
mkdir "system_logs"
mv *.{err,out,log,dag,condor} ./system_logs
mv std_calibration* ./system_logs
mv _condor* ./system_logs
echo "Files sorted. Continuing...."

for appendFile in $PWD/*; do
  if [[ -f "${appendFile}" ]] && [[ "${appendFile##*/}" != "resubmit.sh" ]] && [[ "${appendFile##*/}" != "metadata.json" ]]; then
    echo "Found a file to add..."
    filename="${appendFile##*/}"
    curl -X PUT --data-binary "@$appendFile" $CAPABILITY_SERVICE/capability/request/$capability_request_id/version/latest/files/$filename
  fi
done
echo "All files added."

# submit new version for execution
curl -X POST $CAPABILITY_SERVICE/capability/request/$capability_request_id/submit

"""

old_script = """#!/usr/bin/env bash

set -o errexit -o nounset

# This script is for resubmitting a manually altered standard calibration.
# A new capability request version will be created and all relevant files 
# from the previous version results (contained in the current directory) will be appended to it.

CAPABILITY_SERVICE=$(capo -q edu.nrao.workspaces.CapabilitySettings.serviceUrl)

# create new request version
data_location={{spool_dir}}/rawdata
if [[ -L $data_location ]]; then
    qa="qa2"
    corrected_location="${data_location/spool/"$qa"}"
    params="{"resubmit": true, "rawdata_dir":"location"}"
    corrected_params="${params/location/"$corrected_location"}"
    capability_request_id=$(curl --header "Content-Type: application/json" --request POST --data "$corrected_params" $CAPABILITY_SERVICE/capability/request/execution/{{request_id}}/create_version)
else
    params="{"resubmit": true, "rawdata_dir":"location"}"
    corrected_params="${params/location/"$data_location"}"
    capability_request_id=$(curl --header "Content-Type: application/json" --request POST --data "$corrected_params" $CAPABILITY_SERVICE/capability/request/execution/{{request_id}}/create_version)
fi
# add all files in current directory to new version

# sort files for valid additions
echo "Sorting files...."
mkdir "system_logs"
mv *.{err,out,log,dag,condor} ./system_logs
mv std_calibration* ./system_logs
echo "Files sorted. Continuing...."

for appendFile in $PWD/*; do
  if [[ -f "${appendFile}" ]] && [[ "${appendFile##*/}" != "resubmit.sh" ]] && [[ "${appendFile##*/}" != "metadata.json" ]]; then
    echo "Found a file to add..."
    filename="${appendFile##*/}"
    curl -X PUT --data-binary "@$appendFile" $CAPABILITY_SERVICE/capability/request/$capability_request_id/version/latest/files/$filename
  fi
done
echo "All files added."

# submit new version for execution
curl -X POST $CAPABILITY_SERVICE/capability/request/$capability_request_id/submit

"""


def upgrade():
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{script}' WHERE filename='resubmit.sh' AND workflow_name='std_calibration'
        """
    )


def downgrade():
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{old_script}' WHERE filename='resubmit.sh' AND workflow_name='std_calibration'
        """
    )
