"""update calibration restore for transfer plugin

Revision ID: 88543565c9e5
Revises: 4a69a414ffc7
Create Date: 2021-11-04 15:17:41.634652

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "88543565c9e5"
down_revision = "4a69a414ffc7"
branch_labels = None
depends_on = None


cal_fetch = """executable = std_calibration_fetch.sh
arguments = {{product_locator}}

output = calibration_fetch.out
error = calibration_fetch.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
SPOOL_DIR = {{spool_dir}}
should_transfer_files = yes
transfer_input_files = $ENV(HOME)/.ssh/condor_transfer, nraorsync://$(SBIN_PATH)/pycapo, nraorsync://$(SBIN_PATH)/framework.sh, nraorsync://$(SBIN_PATH)/productfetcher{{#resubmit}}, nraorsync://{{rawdata_dir}}{{/resubmit}}
when_to_transfer_output = ON_EXIT
transfer_output_files = .job.ad
+nrao_output_files = "working rawdata products"
output_destination = nraorsync://$(SPOOL_DIR)
+WantIOProxy = True

getenv = True
environment = "CAPO_PATH=/home/casa/capo"

requirements = HasLustre == True

queue

"""

cal_envoy = """
executable = std_calibration_envoy.sh
arguments = metadata.json PPR.xml

output = calibration_envoy.out
error = calibration_envoy.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
SPOOL_DIR = {{spool_dir}}
should_transfer_files = yes
transfer_input_files = $ENV(HOME)/.ssh/condor_transfer, nraorsync://$(SBIN_PATH)/.matplotlib, nraorsync://$(SBIN_PATH)/pycapo, nraorsync://$(SBIN_PATH)/casa_envoy, nraorsync://$(SBIN_PATH)/vela, nraorsync://$(SPOOL_DIR)/working, nraorsync://$(SPOOL_DIR)/rawdata, nraorsync://$(SPOOL_DIR)/products{{#remote}}, nraorsync://$(SPOOL_DIR)/{{profile}}.properties{{/remote}}, nraorsync://$(SPOOL_DIR)/PPR.xml, nraorsync://$(SPOOL_DIR)/metadata.json{{files_to_transfer}}
transfer_output_files = .job.ad
+nrao_output_files = "working rawdata products"
when_to_transfer_output = ON_EXIT
output_destination = nraorsync://$(SPOOL_DIR)
+WantIOProxy = True

request_memory = {{ramInGb}}
getenv = True

{{^remote}}
environment = "CAPO_PATH=/home/casa/capo"
requirements = HasLustre == True
{{/remote}}
{{#remote}}
requirements = (VLASS == True)
+partition = "VLASS"
Rank = (TARGET.VLASS == True) + (TARGET.VLASSTEST =!= True)
{{/remote}}

queue
"""

cal_convey = """executable = std_calibration_convey.sh
arguments = metadata.json

output = calibration_convey.out
error = calibration_convey.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
SPOOL_DIR = {{spool_dir}}
should_transfer_files = yes
transfer_input_files = $ENV(HOME)/.ssh/condor_transfer, nraorsync://$(SBIN_PATH)/pycapo, nraorsync://$(SBIN_PATH)/conveyor, nraorsync://$(SPOOL_DIR)/metadata.json, nraorsync://$(SPOOL_DIR)/working, nraorsync://$(SPOOL_DIR)/rawdata, nraorsync://$(SPOOL_DIR)/products
+WantIOProxy = True

getenv = True
environment = "CAPO_PATH=/home/casa/capo"
requirements = HasLustre == True

queue

"""

old_cal_fetch = """executable = std_calibration_fetch.sh
arguments = {{product_locator}}

output = calibration_fetch.out
error = calibration_fetch.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/pycapo, $(SBIN_PATH)/framework.sh, $(SBIN_PATH)/productfetcher{{#resubmit}}, {{rawdata_dir}}{{/resubmit}}
transfer_output_files = working, rawdata, products

getenv = True
environment = "CAPO_PATH=/home/casa/capo"

requirements = HasLustre == True

queue
"""

old_cal_envoy = """executable = std_calibration_envoy.sh
arguments = metadata.json PPR.xml

output = calibration_envoy.out
error = calibration_envoy.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/.matplotlib, $(SBIN_PATH)/pycapo, $(SBIN_PATH)/casa_envoy, $(SBIN_PATH)/vela, ./working, ./rawdata, ./products{{#remote}}, {{profile}}.properties{{/remote}}, ./PPR.xml, ./metadata.json{{files_to_transfer}}
transfer_output_files = working, rawdata, products
request_memory = {{ramInGb}}
getenv = True

{{^remote}}
environment = "CAPO_PATH=/home/casa/capo"
requirements = HasLustre == True
{{/remote}}
{{#remote}}
requirements = (VLASS == True)
+partition = "VLASS"
Rank = (TARGET.VLASS == True) + (TARGET.VLASSTEST =!= True)
{{/remote}}

queue

"""

old_cal_convey = """executable = std_calibration_convey.sh
arguments = metadata.json

output = calibration_convey.out
error = calibration_convey.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/pycapo, $(SBIN_PATH)/conveyor, ./metadata.json, ./working, ./rawdata, ./products


getenv = True
environment = "CAPO_PATH=/home/casa/capo"
requirements = HasLustre == True

queue
"""


restore_fetch = """executable = restore_cms_fetch.sh
arguments = {{product_locator}} {{cal_locator}}

output = restore_fetch.out
error = restore_fetch.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
SPOOL_DIR = {{spool_dir}}
should_transfer_files = yes
transfer_input_files = $ENV(HOME)/.ssh/condor_transfer, nraorsync://$(SBIN_PATH)/pycapo, nraorsync://$(SBIN_PATH)/framework.sh, nraorsync://$(SBIN_PATH)/productfetcher
transfer_output_files = .job.ad
+nrao_output_files = "working rawdata products"
output_destination = nraorsync://$(SPOOL_DIR)
+WantIOProxy = True

getenv = True
environment = "CAPO_PATH=/home/casa/capo"

requirements = HasLustre == True

queue
"""

restore_envoy = """executable = restore_cms_envoy.sh
arguments = metadata.json PPR.xml

output = restore_envoy.out
error = restore_envoy.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
SPOOL_DIR = {{spool_dir}}
should_transfer_files = yes
transfer_input_files = $ENV(HOME)/.ssh/condor_transfer, nraorsync://$(SBIN_PATH)/.matplotlib, nraorsync://$(SBIN_PATH)/pycapo, nraorsync://$(SBIN_PATH)/casa_envoy, nraorsync://$(SBIN_PATH)/vela, nraorsync://$(SPOOL_DIR)/working, nraorsync://$(SPOOL_DIR)/rawdata, nraorsync://$(SPOOL_DIR)/products{{#remote}}, nraorsync://$(SPOOL_DIR)/{{profile}}.properties{{/remote}}, nraorsync://$(SPOOL_DIR)/PPR.xml, nraorsync://$(SPOOL_DIR)/metadata.json{{files_to_transfer}}
when_to_transfer_output = ON_EXIT
transfer_output_files = .job.ad 
+nrao_output_files = "working rawdata products"
output_destination = nraorsync://$(SPOOL_DIR)
+WantIOProxy = True

request_memory = {{ramInGb}}
getenv = True

{{^remote}}
environment = "CAPO_PATH=/home/casa/capo"
requirements = HasLustre == True
{{/remote}}
{{#remote}}
requirements = (VLASS == True)
+partition = "VLASS"
Rank = (TARGET.VLASS == True) + (TARGET.VLASSTEST =!= True)
{{/remote}}

queue
"""

restore_deliver = """executable = restore_cms_deliver.sh
arguments = {{request_id}} {{spool_dir}}

output = restore_deliver.out
error = restore_deliver.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $ENV(HOME)/.ssh/condor_transfer, nraorsync://$(SBIN_PATH)/pycapo, nraorsync://$(SBIN_PATH)/deliver

request_memory = {{ramInGb}}
getenv = True
environment = "CAPO_PATH=/home/casa/capo"
requirements = HasLustre == True

queue
"""

old_restore_fetch = """executable = restore_cms_fetch.sh
arguments = {{product_locator}} {{cal_locator}}

output = restore_fetch.out
error = restore_fetch.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/pycapo, $(SBIN_PATH)/framework.sh, $(SBIN_PATH)/productfetcher
transfer_output_files = working, rawdata, products

getenv = True
environment = "CAPO_PATH=/home/casa/capo"

requirements = HasLustre == True

queue
"""

old_restore_envoy = """executable = restore_cms_envoy.sh
arguments = metadata.json PPR.xml

output = restore_envoy.out
error = restore_envoy.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/.matplotlib, $(SBIN_PATH)/pycapo, $(SBIN_PATH)/casa_envoy, $(SBIN_PATH)/vela, ./working, ./rawdata, ./products{{#remote}}, {{profile}}.properties{{/remote}}, ./PPR.xml, ./metadata.json{{files_to_transfer}}
transfer_output_files = working, rawdata, products

request_memory = {{ramInGb}}
getenv = True

{{^remote}}
environment = "CAPO_PATH=/home/casa/capo"
requirements = HasLustre == True
{{/remote}}
{{#remote}}
requirements = (VLASS == True)
+partition = "VLASS"
Rank = (TARGET.VLASS == True) + (TARGET.VLASSTEST =!= True)
{{/remote}}

queue
"""

old_restore_deliver = """executable = restore_cms_deliver.sh
arguments = {{request_id}} {{spool_dir}}

output = restore_deliver.out
error = restore_deliver.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/pycapo, $(SBIN_PATH)/deliver

request_memory = {{ramInGb}}
getenv = True
environment = "CAPO_PATH=/home/casa/capo"
requirements = HasLustre == True

queue
"""


def upgrade():
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{cal_fetch}' WHERE filename='std_calibration_fetch.condor'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{cal_envoy}' WHERE filename='std_calibration_envoy.condor'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{cal_convey}' WHERE filename='std_calibration_convey.condor'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{restore_fetch}' WHERE filename='restore_cms_fetch.condor'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{restore_envoy}' WHERE filename='restore_cms_envoy.condor'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{restore_deliver}' WHERE filename='restore_cms_deliver.condor'
        """
    )


def downgrade():
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{cal_fetch}' WHERE filename='std_calibration_fetch.condor'
        """
    )
    op.execute(
        f"""
            UPDATE workflow_templates
            SET content=E'{cal_envoy}' WHERE filename='std_calibration_envoy.condor'
            """
    )
    op.execute(
        f"""
            UPDATE workflow_templates
            SET content=E'{cal_convey}' WHERE filename='std_calibration_convey.condor'
            """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{old_restore_fetch}' WHERE filename='restore_cms_fetch.condor'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{old_restore_envoy}' WHERE filename='restore_cms_envoy.condor'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{old_restore_deliver}' WHERE filename='restore_cms_deliver.condor'
        """
    )
